Struct pliantdb_core::connection::View [−][src]
pub struct View<'a, Cn, V: View> { pub key: Option<QueryKey<V::Key>>, pub access_policy: AccessPolicy, // some fields omitted }
Parameters to query a schema::View.
Fields
key: Option<QueryKey<V::Key>>Key filtering criteria.
access_policy: AccessPolicyThe view’s data access policy. The default value is AccessPolicy::UpdateBefore.
Implementations
Filters for entries in the view with the range keys.
Sets the access policy for queries.
Executes the query and retrieves the results.
Executes the query and retrieves the results with the associated Documents.
Executes a reduce over the results of the query
Executes a reduce over the results of the query