Trait pliantdb_core::custom_api::CustomApi [−][src]
pub trait CustomApi: Debug + Send + Sync + 'static { type Request: Serialize + for<'de> Deserialize<'de> + Send + Sync + Debug; type Response: Clone + Serialize + for<'de> Deserialize<'de> + Send + Sync + Debug; }
A definition of a custom API. The Request associated type is what a
connected client can send. The Response associated type is what your API
is expecetd to send from the server to the client. The Dispatcher is the
type that will handle the custom API requests.
This feature is powered by actionable through these derives:
Action(trait and derive macro)Actionable(derive macro)
Associated Types
The type that represents an API request. This type is what clients will send to the server.