Enum pliantdb_core::kv::Numeric [−][src]
A numerical value.
Variants
Integer(i64)A 64-bit signed integer.
UnsignedInteger(u64)A 64-bit unsigned integer.
Float(f64)A 64-bit floating point number.
Implementations
Returns this numeric as an i64. If this conversion cannot be done without losing precision or overflowing, None will be returned.
Returns this numeric as an i64, allowing for precision to be lost if the type was not an i64 originally. If saturating is true, the conversion will not allow overflows.
Returns this numeric as an u64. If this conversion cannot be done
without losing precision or overflowing, None will be returned.
Returns this numeric as an u64, allowing for precision to be lost if
the type was not an i64 originally. If saturating is true, the
conversion will not allow overflows.
Returns this numeric as an f64. If this conversion cannot be done
without losing precision, None will be returned.
Returns this numeric as an f64, allowing for precision to be lost if the type was not an f64 originally.