Enum pliantdb_core::kv::Value [−][src]
A value stored in a key.
Variants
A value stored as a byte array.
Numeric(Numeric)A numeric value.
Implementations
Deserializes the bytes contained inside of this value. Returns an error if this value doesn’t contain bytes.
Returns this value as an i64, allowing for precision to be lost if the type was not an i64 originally. If saturating is true, the conversion will not allow overflows. Returns None if the value is bytes.
Returns this value as an u64, allowing for precision to be lost if the type was not an u64 originally. If saturating is true, the conversion will not allow overflows. Returns None if the value is bytes.
Returns this value as an f64, allowing for precision to be lost if the type was not an f64 originally. Returns None if the value is bytes.
Returns this numeric as an i64, allowing for precision to be lost if the type was not an i64 originally. Returns None if the value is bytes.
Returns this numeric as an u64, allowing for precision to be lost if the type was not an u64 originally. Returns None if the value is bytes.