Struct pliantdb_core::schema::Name [−][src]
pub struct Name(_);
A valid schema name. Must be alphanumeric (a-zA-Z9-0) or a hyphen (-).
Cloning this structure shares the underlying string data, regardless of
whether it’s a static string literal or an owned String.
Implementations
pub fn new<T: TryInto<Self, Error = InvalidNameError>>(
contents: T
) -> Result<Self, InvalidNameError>
pub fn new<T: TryInto<Self, Error = InvalidNameError>>(
contents: T
) -> Result<Self, InvalidNameError>Creates a new name after validating it.
Errors
Returns InvalidNameError if the value passed contains any characters
other than a-zA-Z9-0 or a hyphen (-).