Struct pliantdb_core::schema::Schematic[][src]

pub struct Schematic { /* fields omitted */ }
A collection of defined collections and views.

Implementations

Adds the collection C and its views.

Adds the view V.

Returns true if this schema contains the collection C.

Returns true if this schema contains the collection C.

Looks up a view::Serialized by name.

Looks up a view::Serialized through the the type V.

Iterates over all registered views.

Iterates over all views that belong to collection.

Iterates over all views that are unique that belong to collection.