Enum pliantdb_core::transaction::Command[][src]

pub enum Command<'a> {
    Insert {
        contents: Cow<'a, [u8]>,
    },
    Update {
        header: Cow<'a, Header>,
        contents: Cow<'a, [u8]>,
    },
    Delete {
        header: Cow<'a, Header>,
    },
}
A command to execute within a Collection.

Variants

Insert

Inserts a new document containing contents.

Show fields

Fields of Insert

contents: Cow<'a, [u8]>

The initial contents of the document.

Update

Update an existing Document identified by id. revision must match the currently stored revision on the Document. If it does not, the command fill fail with a DocumentConflict error.

Show fields

Fields of Update

header: Cow<'a, Header>

The current header of the Document.

contents: Cow<'a, [u8]>

The new contents to store within the Document.

Delete

Delete an existing Document identified by id. revision must match the currently stored revision on the Document. If it does not, the command fill fail with a DocumentConflict error.

Show fields

Fields of Delete

header: Cow<'a, Header>

The current header of the Document.