Struct pliantdb_core::transaction::ChangedDocument [−][src]
pub struct ChangedDocument {
pub collection: CollectionName,
pub id: u64,
pub deleted: bool,
}Expand description
A record of a changed.
Fields
collection: CollectionNameThe id of the Collection of the changed Document.
id: u64The id of the changed Document.
deleted: boolIf the Document has been deleted, this will be true.