Enum pliantdb_core::Error [−][src]
pub enum Error {
Show variants
SchemaMismatch {
database_name: String,
schema: SchemaName,
stored_schema: SchemaName,
},
SchemaAlreadyRegistered(SchemaName),
SchemaNotRegistered(SchemaName),
InvalidDatabaseName(String),
DatabaseNotFound(String),
DatabaseNameAlreadyTaken(String),
Database(String),
Server(String),
Transport(String),
Websocket(String),
Networking(Error),
Io(String),
Configuration(String),
Client(String),
CollectionNotFound,
DocumentNotFound(CollectionName, u64),
DocumentConflict(CollectionName, u64),
UniqueKeyViolation {
view: ViewName,
conflicting_document_id: u64,
existing_document_id: u64,
},
InvalidName(InvalidNameError),
PermissionDenied(PermissionDenied),
}Expand description
an enumeration of errors that this crate can produce
Variants
The database named database_name was created with a different schema
(stored_schema) than provided (schema).
Show fields
Fields of SchemaMismatch
database_name: StringThe name of the database being accessed.
schema: SchemaNameThe schema provided for the database.
stored_schema: SchemaNameThe schema stored for the database.
SchemaAlreadyRegistered(SchemaName)The SchemaName returned has already been registered with this server.
SchemaNotRegistered(SchemaName)The SchemaName requested was not registered with this server.
InvalidDatabaseName(String)An invalid database name was specified. See
ServerConnection::create_database()
for database name requirements.
DatabaseNotFound(String)The database name given was not found.
DatabaseNameAlreadyTaken(String)The database name already exists.
Database(String)An error from interacting with local storage.
Server(String)An error from interacting with a server.
Transport(String)An error occurred from the QUIC transport layer.
Websocket(String)An error occurred from the websocket transport layer.
Networking(Error)An error occurred from networking.
Io(String)An error occurred from IO.
Configuration(String)An error occurred with the provided configuration options.
Client(String)An error occurred inside of the client.
An attempt to use a Collection with a Database that it wasn’t defined within.
DocumentNotFound(CollectionName, u64)An attempt to update a document that doesn’t exist.
DocumentConflict(CollectionName, u64)When updating a document, if a situation is detected where the contents have changed on the server since the Revision provided, a Conflict error will be returned.
When saving a document in a collection with unique views, a document emits a key that is already emitted by an existing ocument, this error is returned.
Show fields
InvalidName(InvalidNameError)An invalid name was specified during schema creation.
PermissionDenied(PermissionDenied)Permission was denied.