Struct pliantdb_core::schema::Schematic [−][src]
pub struct Schematic { /* fields omitted */ }Expand description
A collection of defined collections and views.
Implementations
Adds the collection C and its views.
Returns true if this schema contains the collection C.
Returns true if this schema contains the collection C.
Looks up a view::Serialized by name.
Looks up a view::Serialized through the the type V.
Iterates over all registered views.
pub fn views_in_collection(
&self,
collection: &CollectionName
) -> Option<Vec<&dyn Serialized>>
pub fn views_in_collection(
&self,
collection: &CollectionName
) -> Option<Vec<&dyn Serialized>>Iterates over all views that belong to collection.
pub fn unique_views_in_collection(
&self,
collection: &CollectionName
) -> Option<Vec<&dyn Serialized>>
pub fn unique_views_in_collection(
&self,
collection: &CollectionName
) -> Option<Vec<&dyn Serialized>>Iterates over all views that are unique that belong to collection.